@@ -215,4 +215,4 @@ class FeatureGenerator(CodeGeneratorBase):
             observable_commands=observable_commands,
             definition_imports=definition_imports,
         )
-        self.generate_file(join(out_dir, f"{self.feature_id_lowercase}_client.pyi"), content, allow_overwrite=True)
+        self.generate_file(join(out_dir, f"{self.feature_id_lowercase}_client.py"), content, allow_overwrite=True)
