@@ -1,8 +1,9 @@
+import os
 import platform
 import sys
 from argparse import ArgumentParser, Namespace
 from glob import glob
-from os.path import dirname, exists, isdir, join
+from os.path import dirname, isdir, join
 from typing import List, Optional
 
 import sila2.code_generator
@@ -50,8 +51,8 @@ def add_features(args: Namespace) -> None:
     package_dir: str = args.package_dir
     new_fdl_files: List[str] = _get_feature_definition_paths(args.feature_definitions)
 
-    if not exists(join(package_dir, "setup.py")):
-        print("Given directory is not a package (does not contain setup.py)", file=sys.stderr)
+    if not {"setup.py", "pyproject.toml"}.intersection(os.listdir(package_dir)):
+        print("Given directory is not a package (does not contain setup.py or pyproject.toml)", file=sys.stderr)
         return
 
     generated_dir = find_matching_directory(join(package_dir, "*", "generated"))
