@@ -1,6 +1,5 @@
-from typing import TYPE_CHECKING
-
 from .authenticationservice_base import AuthenticationServiceBase
+from .authenticationservice_client import AuthenticationServiceClient
 from .authenticationservice_errors import AuthenticationFailed, InvalidAccessToken
 from .authenticationservice_feature import AuthenticationServiceFeature
 from .authenticationservice_types import Login_Responses, Logout_Responses
@@ -8,13 +7,9 @@ from .authenticationservice_types import Login_Responses, Logout_Responses
 __all__ = [
     "AuthenticationServiceBase",
     "AuthenticationServiceFeature",
+    "AuthenticationServiceClient",
     "Login_Responses",
     "Logout_Responses",
     "AuthenticationFailed",
     "InvalidAccessToken",
 ]
-
-if TYPE_CHECKING:
-    from .authenticationservice_client import AuthenticationServiceClient  # noqa: F401
-
-    __all__.append("AuthenticationServiceClient")
