@@ -10,14 +10,6 @@ from .authenticationservice_types import Login_Responses, Logout_Responses
 
 
 class AuthenticationServiceBase(FeatureImplementationBase, ABC):
-
-    """
-    This Feature provides SiLA Clients with access tokens based on a user identification and password.
-    1. the user needs to login with the Login command into the server with a user identification (=user name) and a password
-    2. after verification, an Access Token with the Token Lifetime information will be generated and provided by the server.
-    3. the user can log-out from the server with the Logout command - a valid Access Token is required to run this command.
-    """
-
     @abstractmethod
     def Login(
         self,
