@@ -1,6 +1,5 @@
-from typing import TYPE_CHECKING
-
 from .silaservice_base import SiLAServiceBase
+from .silaservice_client import SiLAServiceClient
 from .silaservice_errors import UnimplementedFeature
 from .silaservice_feature import SiLAServiceFeature
 from .silaservice_types import GetFeatureDefinition_Responses, SetServerName_Responses
@@ -8,12 +7,8 @@ from .silaservice_types import GetFeatureDefinition_Responses, SetServerName_Res
 __all__ = [
     "SiLAServiceBase",
     "SiLAServiceFeature",
+    "SiLAServiceClient",
     "GetFeatureDefinition_Responses",
     "SetServerName_Responses",
     "UnimplementedFeature",
 ]
-
-if TYPE_CHECKING:
-    from .silaservice_client import SiLAServiceClient  # noqa: F401
-
-    __all__.append("SiLAServiceClient")
