@@ -42,7 +42,11 @@ class CompositeMessageMappable(MessageMappable, Generic[T]):
         if len(self) == 0:
             if n_args == 0:
                 return self.message_type()
-            elif len(args) == 1 and not kwargs and args[0] is None:
+            elif (
+                len(args) == 1
+                and not kwargs
+                and (args[0] is None or (isinstance(args[0], tuple) and len(args[0]) == 0))
+            ):
                 return self.message_type()
             else:
                 raise TypeError(f"Expected no arguments, got {args}")
