@@ -10,7 +10,10 @@ if TYPE_CHECKING:
 
 
 class Parameter(NamedDataNode):
+    """Represents a command parameter"""
+
     fully_qualified_identifier: FullyQualifiedIdentifier
+    """Fully qualified parameter identifier"""
     parent_command: Command
 
     def __init__(self, fdl_node, parent_command: Command):
