@@ -10,7 +10,10 @@ if TYPE_CHECKING:
 
 
 class Response(NamedDataNode):
+    """Represents a command response"""
+
     fully_qualified_identifier: FullyQualifiedIdentifier
+    """Fully qualified response identifier"""
     parent_command: Command
 
     def __init__(self, fdl_node, parent_command: Command):
