@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import uuid
 from typing import TYPE_CHECKING
 from typing import Any as TypingAny
 from typing import NamedTuple, Optional, Type
@@ -86,7 +87,7 @@ class Any(DataType):
                  xmlns="http://www.sila-standard.org"
                  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                  xsi:schemaLocation="http://www.sila-standard.org https://gitlab.com/SiLA2/sila_base/raw/master/schema/FeatureDefinition.xsd">
-            <Identifier>Any</Identifier>
+            <Identifier>AnyFeature{str(uuid.uuid4()).replace("-", "")}</Identifier>
             <DisplayName>Any</DisplayName>
             <Description>Dummy feature for the SiLA2 Any type</Description>
             <DataTypeDefinition>
