@@ -10,8 +10,11 @@ if TYPE_CHECKING:
 
 
 class DefinedExecutionErrorNode(NamedNode):
+    """Represents a defined execution error"""
+
     _parent_feature: Feature
     fully_qualified_identifier: FullyQualifiedIdentifier
+    """Fully qualified defined execution error identifier"""
 
     def __init__(self, fdl_node, parent_feature: Feature):
         super().__init__(fdl_node)
