@@ -13,8 +13,19 @@ if TYPE_CHECKING:
 
 
 class ValidationError(SilaError):
+    """
+    Issued by a SiLA Server if a SiLA Client sent invalid command parameters
+
+    Notes
+    -----
+    This error is raised automatically by the SDK if a received parameter violates a constraint defined in the
+    feature definition, or if the SDK could not interpret the parameter message sent by the SiLA Client
+    """
+
     parameter_fully_qualified_identifier: FullyQualifiedIdentifier
+    """Fully qualified identifier of the invalid parameter"""
     message: str
+    """Error message"""
 
     def __init__(self, parameter: Parameter, message: str):
         self.parameter_fully_qualified_identifier = parameter.fully_qualified_identifier
@@ -24,8 +35,8 @@ class ValidationError(SilaError):
         )
 
     def to_message(self) -> SiLAError:
-        return self.pb2_module.SiLAError(
-            validationError=self.pb2_module.ValidationError(
+        return self._pb2_module.SiLAError(
+            validationError=self._pb2_module.ValidationError(
                 parameter=self.parameter_fully_qualified_identifier, message=self.message
             )
         )
