@@ -23,12 +23,15 @@ from sila2.framework.utils import (
 
 if TYPE_CHECKING:
     from sila2.framework.abc.binary_transfer_handler import BinaryTransferHandler
-    from sila2.framework.utils import HasFullyQualifiedIdentifier
+    from sila2.framework.command.intermediate_response import IntermediateResponse
+    from sila2.framework.command.parameter import Parameter
+    from sila2.framework.command.response import Response
 
 
 class Feature(NamedNode):
     _feature_definition: str
     fully_qualified_identifier: FullyQualifiedIdentifier
+    """Fully qualified feature identifier"""
     _sila2_version: str
     _feature_version: str
     _maturity_level: str
@@ -46,9 +49,30 @@ class Feature(NamedNode):
     defined_execution_errors: Dict[str, DefinedExecutionErrorNode]
     metadata_definitions: Dict[str, Metadata]
     _binary_transfer_handler: Optional[BinaryTransferHandler]
-    _children_by_fully_qualified_identifier: Dict[FullyQualifiedIdentifier, HasFullyQualifiedIdentifier]
+    children_by_fully_qualified_identifier: Dict[
+        FullyQualifiedIdentifier,
+        Union[
+            Command,
+            Property,
+            Parameter,
+            Response,
+            IntermediateResponse,
+            DefinedExecutionErrorNode,
+            DataTypeDefinition,
+            Metadata,
+        ],
+    ]
+    """All child elements, accessible by their fully qualified identifier"""
 
     def __init__(self, feature_definition: str) -> None:
+        """
+        Represents a SiLA feature
+
+        Parameters
+        ----------
+        feature_definition
+            Feature definition (XML) as string
+        """
         fdl_node = parse_feature_definition(feature_definition)
         super().__init__(fdl_node)
 
@@ -67,13 +91,13 @@ class Feature(NamedNode):
         self._pb2_module, self._grpc_module = feature_definition_to_modules(fdl_node)
         self._servicer_cls = getattr(self._grpc_module, f"{self._identifier}Servicer")
 
-        self._children_by_fully_qualified_identifier = {}
+        self.children_by_fully_qualified_identifier = {}
 
         self.defined_execution_errors = {}
         for err_node in xpath_sila(fdl_node, "sila:DefinedExecutionError"):
             err = DefinedExecutionErrorNode(err_node, self)
             self.defined_execution_errors[err._identifier] = err
-            self._children_by_fully_qualified_identifier[err.fully_qualified_identifier] = err
+            self.children_by_fully_qualified_identifier[err.fully_qualified_identifier] = err
 
         self._data_type_definitions = {}
         data_type_definition_nodes = list(xpath_sila(fdl_node, "sila:DataTypeDefinition"))
@@ -85,7 +109,7 @@ class Feature(NamedNode):
                 try:
                     dtype = DataTypeDefinition(dtype_node, self)
                     self._data_type_definitions[dtype._identifier] = dtype
-                    self._children_by_fully_qualified_identifier[dtype.fully_qualified_identifier] = dtype
+                    self.children_by_fully_qualified_identifier[dtype.fully_qualified_identifier] = dtype
                 except KeyError:
                     failed_nodes.append(dtype_node)
 
@@ -102,7 +126,7 @@ class Feature(NamedNode):
         self._unobservable_properties = {}
         for prop_node in xpath_sila(fdl_node, "sila:Property"):
             prop = Property.from_fdl_node(prop_node, self)
-            self._children_by_fully_qualified_identifier[prop.fully_qualified_identifier] = prop
+            self.children_by_fully_qualified_identifier[prop.fully_qualified_identifier] = prop
             if isinstance(prop, ObservableProperty):
                 self._observable_properties[prop._identifier] = prop
             elif isinstance(prop, UnobservableProperty):
@@ -114,16 +138,16 @@ class Feature(NamedNode):
         self._unobservable_commands = {}
         for command_node in xpath_sila(fdl_node, "sila:Command"):
             cmd = Command.from_fdl_node(command_node, self)
-            self._children_by_fully_qualified_identifier[cmd.fully_qualified_identifier] = cmd
+            self.children_by_fully_qualified_identifier[cmd.fully_qualified_identifier] = cmd
             for param in cmd.parameters:
-                self._children_by_fully_qualified_identifier[param.fully_qualified_identifier] = param
+                self.children_by_fully_qualified_identifier[param.fully_qualified_identifier] = param
             for resp in cmd.responses:
-                self._children_by_fully_qualified_identifier[resp.fully_qualified_identifier] = resp
+                self.children_by_fully_qualified_identifier[resp.fully_qualified_identifier] = resp
             if isinstance(cmd, ObservableCommand):
                 self._observable_commands[cmd._identifier] = cmd
                 if cmd.intermediate_responses is not None:
                     for int_resp in cmd.intermediate_responses:
-                        self._children_by_fully_qualified_identifier[int_resp.fully_qualified_identifier] = int_resp
+                        self.children_by_fully_qualified_identifier[int_resp.fully_qualified_identifier] = int_resp
             elif isinstance(cmd, UnobservableCommand):
                 self._unobservable_commands[cmd._identifier] = cmd
             else:
@@ -133,19 +157,36 @@ class Feature(NamedNode):
         for meta_node in xpath_sila(fdl_node, "sila:Metadata"):
             meta = Metadata(meta_node, self)
             self.metadata_definitions[meta._identifier] = meta
-            self._children_by_fully_qualified_identifier[meta.fully_qualified_identifier] = meta
+            self.children_by_fully_qualified_identifier[meta.fully_qualified_identifier] = meta
 
         self._binary_transfer_handler = None
 
-    def __getitem__(self, item: str) -> Union[Property, Command, Metadata]:
-        if item in self._unobservable_properties:
-            return self._unobservable_properties[item]
-        if item in self._observable_properties:
-            return self._observable_properties[item]
-        if item in self._unobservable_commands:
-            return self._unobservable_commands[item]
-        if item in self._observable_commands:
-            return self._observable_commands[item]
-        if item in self.metadata_definitions:
-            return self.metadata_definitions[item]
-        raise KeyError(f"Feature '{self._identifier}' has no child command, property or metadata '{item}'")
+    def __getitem__(self, identifier: str) -> Union[Property, Command, Metadata]:
+        """
+        Get a property, command or metadata child element by its identifier
+
+        Parameters
+        ----------
+        identifier
+            Property, command, or metadata identifier
+        Returns
+        -------
+        child_element
+            Child element with the given identifier
+
+        Raises
+        ------
+        KeyError
+            If no such child element exists
+        """
+        if identifier in self._unobservable_properties:
+            return self._unobservable_properties[identifier]
+        if identifier in self._observable_properties:
+            return self._observable_properties[identifier]
+        if identifier in self._unobservable_commands:
+            return self._unobservable_commands[identifier]
+        if identifier in self._observable_commands:
+            return self._observable_commands[identifier]
+        if identifier in self.metadata_definitions:
+            return self.metadata_definitions[identifier]
+        raise KeyError(f"Feature '{self._identifier}' has no child command, property or metadata '{identifier}'")
