@@ -267,7 +267,7 @@ class FeatureImplementationServicer:
         self, parameters: Any, metadata: Dict[FullyQualifiedIdentifier, Any], target: FullyQualifiedIdentifier
     ):
         for interceptor in self.parent_server.metadata_interceptors:
-            if interceptor.required_metadata.issubset(metadata.keys()):
+            if interceptor.affected_metadata.issubset(metadata.keys()):
                 self.logger.info(f"Applying metadata interceptor {interceptor}")
                 interceptor.intercept(parameters, metadata, target)
 
@@ -395,10 +395,10 @@ def raises_rpc_errors(
             context.abort(grpc.StatusCode.UNIMPLEMENTED, "The requested functionality is not implemented")
 
         if not isinstance(ex, SilaError):
-            raise_as_rpc_error(UndefinedExecutionError(ex), context)
+            raise_as_rpc_error(UndefinedExecutionError.from_exception(ex), context)
 
         allowed_error_identifiers = [err.fully_qualified_identifier for err in allowed_defined_execution_errors]
         if isinstance(ex, DefinedExecutionError) and ex.fully_qualified_identifier not in allowed_error_identifiers:
-            raise_as_rpc_error(UndefinedExecutionError(ex), context)
+            raise_as_rpc_error(UndefinedExecutionError.from_exception(ex), context)
 
         raise_as_rpc_error(ex, context)
