@@ -15,7 +15,7 @@ class Stream(Iterator[T]):
 
     def __init__(self):
         self.__queue = Queue()
-        self.__cancelled = True
+        self.__cancelled = False
 
     @classmethod
     def from_queue(cls, queue: Queue[T]):
@@ -25,7 +25,7 @@ class Stream(Iterator[T]):
 
     @property
     def is_alive(self) -> bool:
-        return self.__cancelled
+        return not self.__cancelled
 
     def put(self, item: T) -> None:
         if not self.is_alive:
