@@ -22,22 +22,35 @@ from sila2.server.feature_implementation_servicer import FeatureImplementationSe
 from sila2.server.metadata_interceptor import MetadataInterceptor
 
 if TYPE_CHECKING:
-    from sila2.framework.utils import HasFullyQualifiedIdentifier
+    from sila2.framework.command.command import Command
+    from sila2.framework.command.intermediate_response import IntermediateResponse
+    from sila2.framework.command.parameter import Parameter
+    from sila2.framework.command.response import Response
+    from sila2.framework.data_types.data_type_definition import DataTypeDefinition
+    from sila2.framework.defined_execution_error_node import DefinedExecutionErrorNode
+    from sila2.framework.metadata import Metadata
+    from sila2.framework.property.property import Property
 
 
 class SilaServer:
     grpc_server: grpc.Server
     features: Dict[str, Feature]
     feature_servicers: Dict[str, FeatureImplementationServicer]
-    running: bool
     generated_ca: Optional[bytes]
+    """PEM-encoded certificate authority of self-signed certificate, if generated on server startup"""
 
     server_name: str
+    """SiLA Server Name"""
     server_type: str
+    """SiLA Server Type"""
     server_uuid: UUID
+    """SiLA Server UUID"""
     server_description: str
+    """SiLA Server Description"""
     server_version: str
+    """SiLA Server Version"""
     server_vendor_url: str
+    """SiLA Server Vendor URL"""
 
     service_broadcaster: SilaServiceBroadcaster
     running_instances: List[SilaServiceInfo]
@@ -45,8 +58,23 @@ class SilaServer:
     binary_transfer_handler: ServerBinaryTransferHandler
 
     metadata_interceptors: List[MetadataInterceptor]
+    """Registered metadata interceptors"""
 
-    children_by_fully_qualified_identifier: Dict[FullyQualifiedIdentifier, HasFullyQualifiedIdentifier]
+    children_by_fully_qualified_identifier: Dict[
+        FullyQualifiedIdentifier,
+        Union[
+            Feature,
+            Command,
+            Property,
+            Parameter,
+            Response,
+            IntermediateResponse,
+            DefinedExecutionErrorNode,
+            DataTypeDefinition,
+            Metadata,
+        ],
+    ]
+    """All child elements, accessible by their fully qualified identifier"""
 
     def __init__(
         self,
@@ -59,12 +87,38 @@ class SilaServer:
         max_grpc_workers: int = 100,
         max_child_task_workers: int = 100,
     ):
-        self.running = False
+        """
+        SiLA Server
+
+        Parameters
+        ----------
+        server_name
+            SiLA Server Name, max. 255 characters
+        server_type
+            SiLA Server Type, must start with a capital letter and can only contain letters (a-z, A-Z) and digits (0-9)
+        server_description
+            SiLA Server Description
+        server_version
+            SiLA Server Version, e.g. ``"1.2"``, ``"1.2.3"``, or ``"1.2.3_beta"``.
+
+            Pattern: ``Major.Minor.Patch_Details``,
+            where *Major*, *Minor* und *Patch* are numeric, *Details* is text (a-z, A-Z, 0-9, _).
+            *Patch* and *Details* are optional.
+        server_vendor_url
+            SiLA Server Vendor URL: The product or vendor homepage, must start with ``"http://"`` or ``"https://"``
+        server_uuid
+            SiLA Server UUID. If given as a string, it must be formatted like ``"082bc5dc-18ae-4e17-b028-6115bbc6d21e"``
+        max_grpc_workers
+            Max. number of worker threads used by gRPC
+        max_child_task_workers
+            Max. number of worker threads used by the implementation
+            (e.g. observable command instances, observable property subscriptions, ...)
+        """
+        self.__was_started = False
+        self.__is_running = False
         self.logger = logging.getLogger(__name__)
         self.generated_ca = None
 
-        self.__grpc_server_started = False
-
         # import locally to prevent circular import
         from sila2.features.silaservice import SiLAServiceFeature
         from sila2.server.silaservice_impl import SiLAServiceImpl
@@ -138,9 +192,26 @@ class SilaServer:
 
         self.set_feature_implementation(SiLAServiceFeature, SiLAServiceImpl(parent_server=self))
 
-    def set_feature_implementation(self, feature: Feature, implementation: FeatureImplementationBase):
+    def set_feature_implementation(self, feature: Feature, implementation: FeatureImplementationBase) -> None:
+        """
+        Set a feature implementation
+
+        Parameters
+        ----------
+        feature
+            Feature to implement
+        implementation
+            Feature implementation
+
+        Raises
+        ------
+        RuntimeError
+            If the server was already started, or another implementation of the feature already was set
+        """
+        if self.__was_started:
+            raise RuntimeError("Can only add features before starting the server")
         if feature._identifier in self.feature_servicers:
-            self.feature_servicers[feature._identifier].implementation.stop()
+            raise RuntimeError("Can only add one implementation per feature")
 
         class FeatureServicer(FeatureImplementationServicer, feature._servicer_cls):
             def __init__(self, *args, **kwargs):
@@ -156,9 +227,24 @@ class SilaServer:
 
         feature._binary_transfer_handler = self.binary_transfer_handler
         self.children_by_fully_qualified_identifier[feature.fully_qualified_identifier] = feature
-        self.children_by_fully_qualified_identifier.update(feature._children_by_fully_qualified_identifier)
+        self.children_by_fully_qualified_identifier.update(feature.children_by_fully_qualified_identifier)
 
     def add_metadata_interceptor(self, interceptor: MetadataInterceptor):
+        """
+        Add an interceptor for SiLA Client Metadata handling
+
+        Parameters
+        ----------
+        interceptor
+            Interceptor to add
+
+        Raises
+        ------
+        RuntimeError
+            If the server is already running
+        """
+        if self.__is_running:
+            raise RuntimeError("Cannot add metadata interceptors to running servers")
         self.metadata_interceptors.append(interceptor)
 
     def __start(
@@ -172,7 +258,7 @@ class SilaServer:
         enable_discovery: bool = True,
     ):
         # start grpc server
-        if self.__grpc_server_started:
+        if self.__was_started:
             raise RuntimeError("Cannot start server twice")
 
         address_string = f"{address}:{port}"
@@ -197,7 +283,6 @@ class SilaServer:
             credentials = grpc.ssl_server_credentials([(private_key, cert_chain)])
             self.grpc_server.add_secure_port(address_string, server_credentials=credentials)
         self.grpc_server.start()
-        self.__grpc_server_started = True
 
         # start implementations
         for servicer in self.feature_servicers.values():
@@ -209,9 +294,29 @@ class SilaServer:
             info = self.service_broadcaster.register_server(self, address, port, ca=self.generated_ca)
             self.running_instances.append(info)
 
-        self.running = True
+        self.__is_running = True
+        self.__was_started = True
 
-    def start_insecure(self, address: str, port: int, enable_discovery: bool = True):
+    def start_insecure(self, address: str, port: int, enable_discovery: bool = True) -> None:
+        """
+        Start the server using unencrypted communication
+
+        Parameters
+        ----------
+        address
+            IP address or hostname where the server should run
+        port
+            Port where the server should run
+        enable_discovery
+            Whether to broadcast the server address for SiLA Server Discovery
+
+        Notes
+        -----
+        From the SiLA Specification:
+
+            It is RECOMMENDED that all SiLA Servers have SiLA Server Discovery enabled by default, but all
+            SiLA Devices MUST have SiLA Server Discovery enabled by default.
+        """
         self.__start(address, port, insecure=True, enable_discovery=enable_discovery)
 
     def start(
@@ -222,6 +327,36 @@ class SilaServer:
         cert_chain: bytes = None,
         enable_discovery: bool = True,
     ):
+        """
+        Start the server using unencrypted communication
+
+        When no encryption information is provided, a self-signed certificate is generated.
+        Its PEM-encoded certificate authority is then stored in :py:attr:`sila2.server.SilaServer.generated_ca`.
+
+        Parameters
+        ----------
+        address
+            IP address or hostname where the server should run
+        port
+            Port where the server should run
+        private_key
+            PEM-encoded private key for encrypted communication
+        cert_chain
+            PEM-encoded certificate chain for encrypted communication
+        enable_discovery
+            Whether to broadcast the server address for SiLA Server Discovery
+
+        Warnings
+        --------
+        Using unencrypted communication violates the SiLA specification and should only be used for testing purposes
+
+        Notes
+        -----
+        From the SiLA Specification:
+
+            It is RECOMMENDED that all SiLA Servers have SiLA Server Discovery enabled by default, but all
+            SiLA Devices MUST have SiLA Server Discovery enabled by default.
+        """
         self.__start(
             address,
             port,
@@ -246,14 +381,14 @@ class SilaServer:
         # stop grpc server
         self.grpc_server.stop(grace_period).wait()
 
-        self.running = False
+        self.__is_running = False
 
     def __getitem__(self, item: str) -> Feature:
         return self.features[item]
 
     def __del__(self):
         try:
-            if self.running:
+            if self.__is_running:
                 self.stop()
         except AttributeError:  # when __init__ fails, some attributes might not exist yet, then they cannot be stopped
             pass
